@@ -1,7 +1,7 @@
 use warnings;
 use strict;
 package Mojolicious::Plugin::Authentication;
-$Mojolicious::Plugin::Authentication::VERSION = '1.28';
+$Mojolicious::Plugin::Authentication::VERSION = '1.29';
 use Mojo::Base 'Mojolicious::Plugin';
 
 sub register {
@@ -25,6 +25,7 @@ sub register {
     my $load_user_cb      = $args->{load_user};
     my $validate_user_cb  = $args->{validate_user};
     my $current_user_fn   = $args->{current_user_fn} || 'current_user';
+    my $fail_render       = $args->{fail_render};
 
     # Unconditionally load the user based on uid in session
     my $user_loader_sub = sub {
@@ -68,7 +69,9 @@ sub register {
 
     $app->routes->add_condition(authenticated => sub {
         my ($r, $c, $captures, $required) = @_;
-        return (!$required || $c->is_user_authenticated) ? 1 : 0;
+        my $res = (!$required || $c->is_user_authenticated) ? 1 : 0;
+        $c->render(%$fail_render) if $fail_render && !$res;
+        return $res;
     });
 
     $app->routes->add_condition(signed => sub {
@@ -148,7 +151,7 @@ Mojolicious::Plugin::Authentication - A plugin to make authentication a bit easi
 
 =head1 VERSION
 
-version 1.28
+version 1.29
 
 =head1 SYNOPSIS
 
@@ -163,7 +166,7 @@ version 1.28
     });
 
     if ($self->authenticate('username', 'password', { optional => 'extra data stuff' })) {
-        ... 
+        ...
     }
 
 
@@ -211,7 +214,7 @@ The following options can be set for the plugin:
 
 =item current_user_fn (optional) Set the name for the current_user() helper function
 
-=back 
+=back
 
 In order to set the session expiry time, use the following in your startup routine:
 
@@ -223,7 +226,7 @@ In order to set the session expiry time, use the following in your startup routi
 
 The coderef you pass to the load_user configuration key has the following signature:
 
-    sub { 
+    sub {
         my ($app, $uid) = @_;
         ...
         return $user;
@@ -241,7 +244,7 @@ User validation is what happens when we need to authenticate someone. The codere
         return $uid;
     }
 
-You must return either a user id or undef. The user id can be numerical or a string. Do not return hashrefs, arrayrefs or objects, since the behaviour of this plugin could get a little bit on the odd side of weird if you do that. 
+You must return either a user id or undef. The user id can be numerical or a string. Do not return hashrefs, arrayrefs or objects, since the behaviour of this plugin could get a little bit on the odd side of weird if you do that.
 
 =head1 EXAMPLES
 
@@ -256,7 +259,7 @@ This plugin also exports a routing condition you can use in order to limit acces
     my $authenticated_only = $r->route('/members')->over(authenticated => 1)->to('members#index');
     $authenticated_only->route('online')->to('members#online');
 
-If someone is not authenticated, these routes will not be considered by the dispatcher and unless you have set up a catch-all route, a 404 Not Found will be generated instead. 
+If someone is not authenticated, these routes will not be considered by the dispatcher and unless you have set up a catch-all route, a 404 Not Found will be generated instead.
 
 And another condition for fast and unsecured checking for users, having a signature (without validating it). This method just checks client cookies for uid data existing.
 
@@ -350,10 +353,10 @@ L<http://search.cpan.org/dist/Mojolicious-Plugin-Authentication/>
 
 =head1 ACKNOWLEDGEMENTS
 
-Andrew Parker   
+Andrew Parker
     -   For pointing out some bugs that crept in; a silent reminder not to code while sleepy
 
-Mirko Westermeier (memowe) 
+Mirko Westermeier (memowe)
     -   For doing some (much needed) code cleanup
 
 Terrence Brannon (metaperl)
@@ -371,7 +374,7 @@ Ed W
         a bit more sane.
 
 SailingYYC (Github)
-    -   For reporting an issue with routing conditions; I really should not code while sleepy, brainfarts imminent! 
+    -   For reporting an issue with routing conditions; I really should not code while sleepy, brainfarts imminent!
 
 carragom (Github)
     -   For fixing the bug that'd consider an uid of 0 or "0" to be a problem
